@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Circle_segment_2.h $
+// $Id: Circle_segment_2.h de14c48 2019-01-10T18:52:35+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0+
 //
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -23,6 +24,9 @@
 #ifndef CGAL_CIRCLE_SEGMENT_2_H
 #define CGAL_CIRCLE_SEGMENT_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
 /*! \file
  * Header file for the _Circle_segment_2<Kernel, Filter> class.
  */
@@ -105,6 +109,10 @@ public:
     Point_handle (p)
   {}
 
+#ifndef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
+  _One_root_point_2& operator=(const _One_root_point_2&)=default;
+#endif
+  
   /*! Constructor of a point with one-root coefficients.
      This constructor of a point can also be used with rational coefficients
      thanks to convertor of CoordNT. */
@@ -139,7 +147,7 @@ public:
     return !equals(p);
   }
 
-  bool operator == (const Self& p)
+  bool operator == (const Self& p) const
   {
     return equals(p);
   }
@@ -398,7 +406,7 @@ public:
     NT          y3 = p3.y();
 
 
-    // Make sure that the source and the taget are not the same.
+    // Make sure that the source and the target are not the same.
     CGAL_precondition (Kernel().compare_xy_2_object() (p1, p3) != EQUAL);
 
     // Compute the lines: A1*x + B1*y + C1 = 0,
@@ -529,7 +537,7 @@ public:
 
   /*!
    * Get the vertical tangency points the arc contains.
-   * \param vpts Output: The vertical tagnecy points.
+   * \param vpts Output: The vertical tangency points.
    * \pre The curve is circular.
    * \return The number of points (0, 1, or 2).
    */
@@ -590,8 +598,8 @@ private:
 
   /*!
    * Get the vertical tangency points the arc contains, assuming it is
-   * counterclockwise oreinted.
-   * \param vpts Output: The vertical tagnecy points.
+   * counterclockwise oriented.
+   * \param vpts Output: The vertical tangency points.
    * \return The number of points (0, 1, or 2).
    */
   unsigned int _ccw_vertical_tangency_points (const Point_2& src,
@@ -2033,9 +2041,9 @@ protected:
     if (CGAL::sign(denom) == ZERO)
       return;
 
-    const NT      x_numer = b()*cv.c() - c()*cv.b();
-    const NT      y_numer = c()*cv.a() - a()*cv.c();
-    Point_2       p (x_numer / denom, y_numer / denom);
+    const NT      x = (b()*cv.c() - c()*cv.b()) / denom;
+    const NT      y = (c()*cv.a() - a()*cv.c()) / denom;
+    Point_2       p (x, y);
 
     inter_list.push_back (Intersection_point_2 (p, mult));
     return;
@@ -2437,7 +2445,7 @@ protected:
     {
       x = x_left + x_jump*i;
       disc = app_sqr_rad - CGAL::square(x - app_xcenter);
-      CGAL_precondition(disc >= 0);
+      if (disc < 0) disc = 0;
       if(is_up)
         y = app_ycenter + std::sqrt(disc);
       else
