@@ -51,8 +51,9 @@
  * WWW URL: http://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL$
- * $Id$
+ * $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/CGAL_Core/include/CGAL/CORE/poly/Sturm.h $
+ * $Id: Sturm.h 6b568a8 2017-11-11T21:06:17+01:00 Sébastien Loriot
+ * SPDX-License-Identifier: LGPL-3.0+
  ***************************************************************************/
 
 
@@ -82,8 +83,7 @@ public:
   Polynomial<NT> g;//GCD of input polynomial P and it's derivative P'
   NT cont;//Content of the square-free part of input polynomial P
   //Thus P = g * cont * seq[0]
-  static int N_STOP_ITER;    // Stop IterE after this many iterations. This
-  // is initialized below, outside the Newton class
+  static const int N_STOP_ITER = 10000;    // Stop IterE after this many iterations. 
   bool NEWTON_DIV_BY_ZERO;   // This is set to true when there is divide by
   // zero in Newton iteration (at critical value)
   // User is responsible to check this and to reset.
@@ -1075,12 +1075,6 @@ std::cout << "In newtonRefine, input J=" << J.first
 
 };// Sturm class
 
-// ==================================================
-// Static initialization
-// ==================================================
-template <class NT>
-int Sturm<NT>:: N_STOP_ITER = 10000;   // stop IterE after this many loops
-// Reset this as needed
 
 // ==================================================
 // Helper Functions 
