@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/STL_Extension/include/CGAL/Concurrent_compact_container.h $
+// $Id: Concurrent_compact_container.h 6ded244 2019-12-04T15:32:07+01:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0+
 //
 // Author(s)     : Clement Jamin
@@ -32,10 +32,14 @@
 #include <algorithm>
 #include <vector>
 #include <cstring>
+#include <cstddef>
+
+#include <CGAL/Compact_container.h>
 
 #include <CGAL/memory.h>
 #include <CGAL/iterator.h>
 #include <CGAL/CC_safe_handle.h>
+#include <CGAL/Time_stamper.h>
 #include <CGAL/atomic.h>
 
 #include <tbb/enumerable_thread_specific.h>
@@ -75,9 +79,6 @@ struct Concurrent_compact_container_traits {
 };
 
 namespace CCC_internal {
-  template < class CCC, bool Const >
-  class CCC_iterator;
-  
   CGAL_GENERATE_MEMBER_DETECTOR(increment_erase_counter);
   
   // A basic "no erase counter" strategy
@@ -123,15 +124,37 @@ namespace CCC_internal {
 template< typename pointer, typename size_type, typename CCC >
 class Free_list {
 public:
-  Free_list() : m_head(NULL), m_size(0) {}
+  Free_list() : m_head(NULL), m_size(0) {
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    // Note that the performance penalty with
+    // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE=1 is
+    // measured to be 3%, in a parallel insertion of 100k random
+    // points, in Delaunay_triangulation_3.
+    refresh_approximate_size();
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  }
 
   void init()                { m_head = NULL; m_size = 0; }
   pointer head() const       { return m_head; }
   void set_head(pointer p)   { m_head = p; }
   size_type size() const     { return m_size; }
-  void set_size(size_type s) { m_size = s; }
-  void inc_size()            { ++m_size; }
-  void dec_size()            { --m_size; }
+  void set_size(size_type s) {
+    m_size = s;
+  }
+  void inc_size() {
+    ++m_size;
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    if(m_size > (m_approximate_size * precision_of_approximate_size_plus_1))
+      refresh_approximate_size();
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  }
+  void dec_size() {
+    --m_size;
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    if((m_size * precision_of_approximate_size_plus_1) < m_approximate_size)
+      refresh_approximate_size();
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  }
   bool empty()               { return size() == 0; }
   // Warning: copy the pointer, not the data!
   Free_list& operator= (const Free_list& other)
@@ -157,9 +180,26 @@ public:
     other.init(); // clear other
   }
 
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  size_type approximate_size() const {
+    return m_atomic_approximate_size.load(std::memory_order_relaxed);
+  }
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+
 protected:
   pointer   m_head;  // the free list head pointer
   size_type m_size;  // the free list size
+
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  // `m_size` plus or minus `precision_of_approximate_size - 1`
+  static constexpr double precision_of_approximate_size_plus_1 = 1.10;
+  size_type m_approximate_size;
+  std::atomic<size_type> m_atomic_approximate_size;
+  void refresh_approximate_size() {
+    m_approximate_size = m_size;
+    m_atomic_approximate_size.store(m_size, std::memory_order_relaxed);
+  }
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
 };
 
 // Class Concurrent_compact_container
@@ -176,6 +216,8 @@ class Concurrent_compact_container
   typedef Concurrent_compact_container_traits <T>                   Traits;
 
 public:
+  typedef CGAL::Time_stamper_impl<T>                Time_stamper_impl;
+
   typedef T                                         value_type;
   typedef Allocator                                 allocator_type;
 
@@ -194,8 +236,8 @@ public:
   typedef typename Allocator::difference_type       difference_type;
 #endif
 
-  typedef CCC_internal::CCC_iterator<Self, false>   iterator;
-  typedef CCC_internal::CCC_iterator<Self, true>    const_iterator;
+  typedef internal::CC_iterator<Self, false>        iterator;
+  typedef internal::CC_iterator<Self, true>         const_iterator;
   typedef std::reverse_iterator<iterator>           reverse_iterator;
   typedef std::reverse_iterator<const_iterator>     const_reverse_iterator;
 
@@ -207,11 +249,12 @@ private:
   friend class Free_list<pointer, size_type, Self>;
 
 public:
-  friend class CCC_internal::CCC_iterator<Self, false>;
-  friend class CCC_internal::CCC_iterator<Self, true>;
+  friend class internal::CC_iterator<Self, false>;
+  friend class internal::CC_iterator<Self, true>;
 
   explicit Concurrent_compact_container(const Allocator &a = Allocator())
   : m_alloc(a)
+  , m_time_stamper(new Time_stamper_impl())
   {
     init ();
   }
@@ -220,6 +263,7 @@ public:
   Concurrent_compact_container(InputIterator first, InputIterator last,
                     const Allocator & a = Allocator())
   : m_alloc(a)
+  , m_time_stamper(new Time_stamper_impl())
   {
     init();
     std::copy(first, last, CGAL::inserter(*this));
@@ -228,6 +272,7 @@ public:
   // The copy constructor and assignment operator preserve the iterator order
   Concurrent_compact_container(const Concurrent_compact_container &c)
   : m_alloc(c.get_allocator())
+  , m_time_stamper(new Time_stamper_impl())
   {
     init();
     m_block_size = c.m_block_size;
@@ -246,6 +291,7 @@ public:
   ~Concurrent_compact_container()
   {
     clear();
+    delete m_time_stamper;
   }
 
   bool is_used(const_iterator ptr) const
@@ -256,17 +302,22 @@ public:
   void swap(Self &c)
   {
     std::swap(m_alloc, c.m_alloc);
-    std::swap(m_capacity, c.m_capacity);
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
     { // non-atomic swap
-      size_type other_size = c.m_size;
-      c.m_size = size_type(m_size);
-      m_size = other_size;
+      size_type other_capacity = c.m_capacity;
+      c.m_capacity = size_type(m_capacity);
+      m_capacity = other_capacity;
     }
+#else // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    std::swap(m_capacity, c.m_capacity);
+#endif // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+
     std::swap(m_block_size, c.m_block_size);
     std::swap(m_first_item, c.m_first_item);
     std::swap(m_last_item, c.m_last_item);
     std::swap(m_free_lists, c.m_free_lists);
     m_all_items.swap(c.m_all_items);
+    std::swap(m_time_stamper, c.m_time_stamper);
   }
 
   iterator begin() { return iterator(m_first_item, 0, 0); }
@@ -452,7 +503,6 @@ private:
 #ifndef CGAL_NO_ASSERTIONS
     std::memset(&*x, 0, sizeof(T));
 #endif*/
-    --m_size;
     put_on_free_list(&*x, fl);
   }
 public:
@@ -473,12 +523,14 @@ public:
   // The complexity is O(size(free list = capacity-size)).
   void merge(Self &d);
 
-  // If `CGAL_NO_ATOMIC` is defined, do not call this function while others
-  // are inserting/erasing elements
+  // Do not call this function while others are inserting/erasing elements
   size_type size() const
   {
-#ifdef CGAL_NO_ATOMIC
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    size_type size = m_capacity.load(std::memory_order_relaxed);
+#else // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
     size_type size = m_capacity;
+#endif // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
     for( typename Free_lists::iterator it_free_list = m_free_lists.begin() ;
          it_free_list != m_free_lists.end() ;
          ++it_free_list )
@@ -486,11 +538,22 @@ public:
       size -= it_free_list->size();
     }
     return size;
-#else // atomic can be used
-    return m_size;
-#endif
   }
 
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  size_type approximate_size() const
+  {
+    size_type size = m_capacity.load(std::memory_order_relaxed);
+    for( typename Free_lists::iterator it_free_list = m_free_lists.begin() ;
+         it_free_list != m_free_lists.end() ;
+         ++it_free_list )
+    {
+      size -= it_free_list->approximate_size();
+    }
+    return size;
+  }
+#endif // CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+
   size_type max_size() const
   {
 #ifdef CGAL_CXX11
@@ -502,7 +565,11 @@ public:
 
   size_type capacity() const
   {
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    return m_capacity.load(std::memory_order_relaxed);
+#else // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
     return m_capacity;
+#endif // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
   }
 
   // void resize(size_type sz, T c = T()); // TODO  makes sense ???
@@ -600,7 +667,7 @@ private:
   {
     CGAL_assertion(type(ret) == USED);
     fl->dec_size();
-    ++m_size;
+    m_time_stamper->set_time_stamp(ret);
     return iterator(ret, 0);
   }
 
@@ -633,7 +700,8 @@ private:
 
   static char * clean_pointer(char * p)
   {
-    return ((p - (char *) NULL) & ~ (std::ptrdiff_t) START_END) + (char *) NULL;
+    return reinterpret_cast<char*>(reinterpret_cast<std::ptrdiff_t>(p) &
+                                   ~ (std::ptrdiff_t) START_END);
   }
 
   // Returns the pointee, cleaned up from the squatted bits.
@@ -646,20 +714,23 @@ private:
   static Type type(const_pointer ptr)
   {
     char * p = (char *) Traits::pointer(*ptr);
-    return (Type) (p - clean_pointer(p));
+    return (Type) (reinterpret_cast<std::ptrdiff_t>(p) -
+                   reinterpret_cast<std::ptrdiff_t>(clean_pointer(p)));
   }
 
-  static Type type(const_iterator ptr)
+  static Type type(const_iterator it)
   {
-    return type(&*ptr);
+    return type(it.operator->());
   }
 
   // Sets the pointer part and the type of the pointee.
-  static void set_type(pointer p_element, void * pointer, Type t)
+  static void set_type(pointer ptr, void * p, Type t)
   {
-    CGAL_precondition(0 <= t && (int) t < 4);
-    Traits::pointer(*p_element) =
-      (void *) ((clean_pointer((char *) pointer)) + (int) t);
+    // This out of range compare is always true and causes lots of
+    // unnecessary warnings.
+    // CGAL_precondition(0 <= t && t < 4);
+    Traits::pointer(*ptr) = reinterpret_cast<void *>
+      (reinterpret_cast<std::ptrdiff_t>(clean_pointer((char *) p)) + (int) t);
   }
 
   typedef tbb::queuing_mutex Mutex;
@@ -688,28 +759,30 @@ private:
     m_first_item = NULL;
     m_last_item  = NULL;
     m_all_items  = All_items();
-    m_size = 0;
+    m_time_stamper->reset();
   }
 
   allocator_type    m_alloc;
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  std::atomic<size_type> m_capacity;
+#else // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
   size_type         m_capacity;
+#endif // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
   size_type         m_block_size;
   Free_lists        m_free_lists;
   pointer           m_first_item;
   pointer           m_last_item;
   All_items         m_all_items;
   mutable Mutex     m_mutex;
-#ifdef CGAL_NO_ATOMIC
-  size_type         m_size;
-#else
-  CGAL::cpp11::atomic<size_type> m_size;
-#endif
+
+  // This is a pointer, so that the definition of Compact_container does
+  // not require a complete type `T`.
+  Time_stamper_impl* m_time_stamper;
 };
 
 template < class T, class Allocator >
 void Concurrent_compact_container<T, Allocator>::merge(Self &d)
 {
-  m_size += d.m_size;
   CGAL_precondition(&d != this);
 
   // Allocators must be "compatible" :
@@ -748,7 +821,11 @@ void Concurrent_compact_container<T, Allocator>::merge(Self &d)
   }
   m_all_items.insert(m_all_items.end(), d.m_all_items.begin(), d.m_all_items.end());
   // Add the capacities.
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+  m_capacity.fetch_add(d.m_capacity, std::memory_order_relaxed);
+#else // not  CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
   m_capacity += d.m_capacity;
+#endif // not  CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
   // It seems reasonnable to take the max of the block sizes.
   m_block_size = (std::max)(m_block_size, d.m_block_size);
   // Clear d.
@@ -786,7 +863,11 @@ void Concurrent_compact_container<T, Allocator>::
     old_block_size = m_block_size;
     new_block = m_alloc.allocate(old_block_size + 2);
     m_all_items.push_back(std::make_pair(new_block, old_block_size + 2));
+#if CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
+    m_capacity.fetch_add(old_block_size, std::memory_order_relaxed);
+#else // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
     m_capacity += old_block_size;
+#endif // not CGAL_CONCURRENT_COMPACT_CONTAINER_APPROXIMATE_SIZE
 
     // We insert this new block at the end.
     if (m_last_item == NULL) // First time
@@ -812,6 +893,7 @@ void Concurrent_compact_container<T, Allocator>::
   for (size_type i = old_block_size; i >= 1; --i)
   {
     EraseCounterStrategy::set_erase_counter(*(new_block + i), 0);
+    m_time_stamper->initialize_time_stamp(new_block + i);
     put_on_free_list(new_block + i, fl);
   }
 }
@@ -866,243 +948,7 @@ bool operator>=(const Concurrent_compact_container<T, Allocator> &lhs,
   return ! (lhs < rhs);
 }
 
-namespace CCC_internal {
-
-  template < class CCC, bool Const >
-  class CCC_iterator
-  {
-    typedef typename CCC::iterator                    iterator;
-    typedef CCC_iterator<CCC, Const>                   Self;
-  public:
-    typedef typename CCC::value_type                  value_type;
-    typedef typename CCC::size_type                   size_type;
-    typedef typename CCC::difference_type             difference_type;
-    typedef typename boost::mpl::if_c< Const, const value_type*,
-                                       value_type*>::type pointer;
-    typedef typename boost::mpl::if_c< Const, const value_type&,
-                                       value_type&>::type reference;
-    typedef std::bidirectional_iterator_tag           iterator_category;
-
-    // the initialization with NULL is required by our Handle concept.
-    CCC_iterator()
-    {
-      m_ptr.p = NULL;
-    }
-
-    // Either a harmless copy-ctor,
-    // or a conversion from iterator to const_iterator.
-    CCC_iterator (const iterator &it)
-    {
-      m_ptr.p = &(*it);
-    }
-
-    // Same for assignment operator (otherwise MipsPro warns)
-    CCC_iterator & operator= (const iterator &it)
-    {
-      m_ptr.p = &(*it);
-      return *this;
-    }
-
-    // Construction from NULL
-    CCC_iterator (Nullptr_t CGAL_assertion_code(n))
-    {
-      CGAL_assertion (n == NULL);
-      m_ptr.p = NULL;
-    }
-
-  private:
-
-    union {
-      pointer      p;
-      void        *vp;
-    } m_ptr;
-
-    // Only Concurrent_compact_container should access these constructors.
-    friend class Concurrent_compact_container<value_type, typename CCC::Al>;
-
-    // For begin()
-    CCC_iterator(pointer ptr, int, int)
-    {
-      m_ptr.p = ptr;
-      if (m_ptr.p == NULL) // empty container.
-        return;
-
-      ++(m_ptr.p); // if not empty, p = start
-      if (CCC::type(m_ptr.p) == CCC::FREE)
-        increment();
-    }
-
-    // Construction from raw pointer and for end().
-    CCC_iterator(pointer ptr, int)
-    {
-      m_ptr.p = ptr;
-    }
-
-    // NB : in case empty container, begin == end == NULL.
-    void increment()
-    {
-      // It's either pointing to end(), or valid.
-      CGAL_assertion_msg(m_ptr.p != NULL,
-        "Incrementing a singular iterator or an empty container iterator ?");
-      CGAL_assertion_msg(CCC::type(m_ptr.p) != CCC::START_END,
-        "Incrementing end() ?");
-
-      // If it's not end(), then it's valid, we can do ++.
-      do {
-        ++(m_ptr.p);
-        if (CCC::type(m_ptr.p) == CCC::USED ||
-            CCC::type(m_ptr.p) == CCC::START_END)
-          return;
-
-        if (CCC::type(m_ptr.p) == CCC::BLOCK_BOUNDARY)
-          m_ptr.p = CCC::clean_pointee(m_ptr.p);
-      } while (true);
-    }
-
-    void decrement()
-    {
-      // It's either pointing to end(), or valid.
-      CGAL_assertion_msg(m_ptr.p != NULL,
-        "Decrementing a singular iterator or an empty container iterator ?");
-      CGAL_assertion_msg(CCC::type(m_ptr.p - 1) != CCC::START_END,
-        "Decrementing begin() ?");
-
-      // If it's not begin(), then it's valid, we can do --.
-      do {
-        --m_ptr.p;
-        if (CCC::type(m_ptr.p) == CCC::USED ||
-            CCC::type(m_ptr.p) == CCC::START_END)
-          return;
-
-        if (CCC::type(m_ptr.p) == CCC::BLOCK_BOUNDARY)
-          m_ptr.p = CCC::clean_pointee(m_ptr.p);
-      } while (true);
-    }
-
-  public:
-
-    Self & operator++()
-    {
-      CGAL_assertion_msg(m_ptr.p != NULL,
-   "Incrementing a singular iterator or an empty container iterator ?");
-      /* CGAL_assertion_msg(CCC::type(m_ptr.p) == CCC::USED,
-         "Incrementing an invalid iterator."); */
-      increment();
-      return *this;
-    }
-
-    Self & operator--()
-    {
-      CGAL_assertion_msg(m_ptr.p != NULL,
-   "Decrementing a singular iterator or an empty container iterator ?");
-      /* CGAL_assertion_msg(CCC::type(m_ptr.p) == CCC::USED
-          || CCC::type(m_ptr.p) == CCC::START_END,
-          "Decrementing an invalid iterator."); */
-      decrement();
-      return *this;
-    }
-
-    Self operator++(int) { Self tmp(*this); ++(*this); return tmp; }
-    Self operator--(int) { Self tmp(*this); --(*this); return tmp; }
-
-    reference operator*() const { return *(m_ptr.p); }
-
-    pointer   operator->() const { return (m_ptr.p); }
-
-    // For std::less...
-    bool operator<(const CCC_iterator& other) const
-    {
-      return (m_ptr.p < other.m_ptr.p);
-    }
-
-    bool operator>(const CCC_iterator& other) const
-    {
-      return (m_ptr.p > other.m_ptr.p);
-    }
-
-    bool operator<=(const CCC_iterator& other) const
-    {
-      return (m_ptr.p <= other.m_ptr.p);
-    }
-
-    bool operator>=(const CCC_iterator& other) const
-    {
-      return (m_ptr.p >= other.m_ptr.p);
-    }
-
-    // Can itself be used for bit-squatting.
-    void *   for_compact_container() const { return (m_ptr.vp); }
-    void * & for_compact_container()       { return (m_ptr.vp); }
-  };
-
-  template < class CCC, bool Const1, bool Const2 >
-  inline
-  bool operator==(const CCC_iterator<CCC, Const1> &rhs,
-                  const CCC_iterator<CCC, Const2> &lhs)
-  {
-    return rhs.operator->() == lhs.operator->();
-  }
-
-  template < class CCC, bool Const1, bool Const2 >
-  inline
-  bool operator!=(const CCC_iterator<CCC, Const1> &rhs,
-                  const CCC_iterator<CCC, Const2> &lhs)
-  {
-    return rhs.operator->() != lhs.operator->();
-  }
-
-  // Comparisons with NULL are part of CGAL's Handle concept...
-  template < class CCC, bool Const >
-  inline
-  bool operator==(const CCC_iterator<CCC, Const> &rhs,
-                  Nullptr_t CGAL_assertion_code(n))
-  {
-    CGAL_assertion( n == NULL);
-    return rhs.operator->() == NULL;
-  }
-
-  template < class CCC, bool Const >
-  inline
-  bool operator!=(const CCC_iterator<CCC, Const> &rhs,
-      Nullptr_t CGAL_assertion_code(n))
-  {
-    CGAL_assertion( n == NULL);
-    return rhs.operator->() != NULL;
-  }
-
-  template <class CCC, bool Const>
-  std::size_t hash_value(const CCC_iterator<CCC, Const>&  i)
-  {
-    return reinterpret_cast<std::size_t>(&*i) / sizeof(typename CCC::value_type);
-  }
-} // namespace CCC_internal
-
 } //namespace CGAL
-namespace std {
-
-#if defined(BOOST_MSVC)
-#  pragma warning(push)
-#  pragma warning(disable:4099) // For VC10 it is class hash 
-#endif
-
-#ifndef CGAL_CFG_NO_STD_HASH
-  
-  template < class CCC, bool Const >
-  struct hash<CGAL::CCC_internal::CCC_iterator<CCC, Const> >
-    : public CGAL::cpp98::unary_function<CGAL::CCC_internal::CCC_iterator<CCC, Const>, std::size_t> {
-
-    std::size_t operator()(const CGAL::CCC_internal::CCC_iterator<CCC, Const>& i) const
-    {
-      return reinterpret_cast<std::size_t>(&*i) / sizeof(typename CCC::value_type);
-    }
-  };
-#endif // CGAL_CFG_NO_STD_HASH
-
-#if defined(BOOST_MSVC)
-#  pragma warning(pop)
-#endif
-
-} // namespace std
 
 #include <CGAL/enable_warnings.h>
 
