@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Mesh_3/include/CGAL/Mesh_3/Worksharing_data_structures.h $
+// $Id: Worksharing_data_structures.h 49d526c 2019-07-29T14:30:03+02:00 Jane Tournois
 // SPDX-License-Identifier: GPL-3.0+
 //
 // Author(s)     : Clement Jamin
@@ -160,11 +160,11 @@ public:
   {
     // Compute indices on grid
     int index_x = static_cast<int>( (to_double(point.x()) - m_xmin) * m_resolution_x);
-    index_x = std::max( 0, std::min(index_x, m_num_grid_cells_per_axis - 1) );
+    index_x = (std::max)( 0, (std::min)(index_x, m_num_grid_cells_per_axis - 1) );
     int index_y = static_cast<int>( (to_double(point.y()) - m_ymin) * m_resolution_y);
-    index_y = std::max( 0, std::min(index_y, m_num_grid_cells_per_axis - 1) );
+    index_y = (std::max)( 0, (std::min)(index_y, m_num_grid_cells_per_axis - 1) );
     int index_z = static_cast<int>( (to_double(point.z()) - m_zmin) * m_resolution_z);
-    index_z = std::max( 0, std::min(index_z, m_num_grid_cells_per_axis - 1) );
+    index_z = (std::max)( 0, (std::min)(index_z, m_num_grid_cells_per_axis - 1) );
 
     int index =
       index_z*m_num_grid_cells_per_axis*m_num_grid_cells_per_axis
@@ -646,16 +646,16 @@ protected:
     int index_x = cell_index;
 
     // For each cell inside the square
-    for (int i = std::max(0, index_x-occupation_radius) ;
-          i <= std::min(m_num_cells_per_axis - 1, index_x+occupation_radius) ;
+    for (int i = (std::max)(0, index_x-occupation_radius) ;
+          i <= (std::min)(m_num_cells_per_axis - 1, index_x+occupation_radius) ;
           ++i)
     {
-      for (int j = std::max(0, index_y-occupation_radius) ;
-            j <= std::min(m_num_cells_per_axis - 1, index_y+occupation_radius) ;
+      for (int j = (std::max)(0, index_y-occupation_radius) ;
+            j <= (std::min)(m_num_cells_per_axis - 1, index_y+occupation_radius) ;
             ++j)
       {
-        for (int k = std::max(0, index_z-occupation_radius) ;
-              k <= std::min(m_num_cells_per_axis - 1, index_z+occupation_radius) ;
+        for (int k = (std::max)(0, index_z-occupation_radius) ;
+              k <= (std::min)(m_num_cells_per_axis - 1, index_z+occupation_radius) ;
               ++k)
         {
           int index =
