@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Nef_3/include/CGAL/Nef_3/SNC_point_locator.h $
+// $Id: SNC_point_locator.h 4fbd1ed 2020-01-16T14:14:13+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 // 
 //
 // Author(s)     : Miguel Granados <granados@mpi-sb.mpg.de>
@@ -21,19 +22,16 @@
 #ifndef CGAL_NEF_SNC_POINT_LOCATOR_H
 #define CGAL_NEF_SNC_POINT_LOCATOR_H
 
+#include <CGAL/license/Nef_3.h>
+
+
 #include <CGAL/basic.h>
 #include <CGAL/Nef_3/SNC_intersection.h>
-#ifdef CGAL_NEF3_POINT_LOCATOR_NAIVE
-#include <CGAL/Nef_3/SNC_ray_shooter.h>
-#endif
-#ifdef CGAL_NEF3_LAZY_KDTREE
-#include <CGAL/Nef_3/Lazy_k3_tree.h>
-#endif
 #include <CGAL/Nef_3/SNC_k3_tree_traits.h>
 #include <CGAL/Nef_3/K3_tree.h>
 #include <CGAL/Unique_hash_map.h>
 #include <CGAL/Timer.h>
-#include <cstring> // for std::strcpy
+#include <string>
 
 #ifdef CGAL_NEF3_TRIANGULATE_FACETS
 #include <CGAL/Constrained_triangulation_2.h>
@@ -72,7 +70,7 @@ class SNC_point_locator
   typedef typename SNC_decorator::Decorator_traits Decorator_traits;
   typedef typename SNC_decorator::SNC_structure SNC_structure;
 protected:
-  char version_[64];
+  std::string version_;
   // time for construction, point location, ray shooting and intersection test
   mutable Timer ct_t, pl_t, rs_t, it_t; 
 
@@ -95,7 +93,7 @@ public:
   typedef typename Decorator_traits::Halffacet_iterator Halffacet_iterator;
 
 
-  const char* version() { return version_; }
+  const std::string& version() const { return version_; }
 
   virtual Object_handle locate(const Point_3& p) const = 0;
 
@@ -169,11 +167,8 @@ class SNC_point_locator_by_spatial_subdivision :
 
 public:
   typedef typename CGAL::SNC_k3_tree_traits<SNC_decorator> K3_tree_traits;
-#ifdef CGAL_NEF3_LAZY_KDTREE
-  typedef typename CGAL::Lazy_k3_tree<K3_tree_traits> K3_tree;
-#else
+
   typedef typename CGAL::K3_tree<K3_tree_traits> K3_tree;
-#endif
   typedef K3_tree SNC_candidate_provider;
   
   typedef typename SNC_structure::Object_handle Object_handle;
@@ -313,7 +308,7 @@ public:
     candidate_provider = new SNC_candidate_provider(W);
 #else // CGAL_NEF_LIST_OF_TRIANGLES
     CGAL_NEF_TIMER(ct_t.start());
-    std::strcpy( this->version_, "Point Locator by Spatial Subdivision (tm)");
+    this->version_ = std::string("Point Locator by Spatial Subdivision (tm)");
 #ifdef CGAL_NEF3_TRIANGULATE_FACETS
     CGAL_NEF_CLOG(version()<<" (with triangulated facets)");
 #else
@@ -408,12 +403,10 @@ public:
     }
     if(initialized)
       delete candidate_provider;
-#ifdef CGAL_NEF3_LAZY_KDTREE
-    candidate_provider = new SNC_candidate_provider(objects,v_end);
-#else
+
     Object_list_iterator oli=objects.begin()+v_end;
     candidate_provider = new SNC_candidate_provider(objects,oli);
-#endif
+
     // CGAL_NEF_TRACEN(*candidate_provider);
     CGAL_NEF_TIMER(ct_t.stop());
 #endif // CGAL_NEF_LIST_OF_TRIANGLES
@@ -900,7 +893,7 @@ public:
       else CGAL_error_msg( "wrong handle type");
     }
 
-    CGAL_warning("altered code in SNC_point_locator");
+    //CGAL_warning("altered code in SNC_point_locator");
     /*
       Halffacet_iterator fc;
       CGAL_forall_facets(fc, *this->sncp()) {
@@ -923,7 +916,7 @@ public:
     if( CGAL::assign( v, result)) {
       _CGAL_NEF_TRACEN("vertex hit, obtaining volume..." << v->point());
 
-      CGAL_warning("altered code in SNC_point_locator");
+      //CGAL_warning("altered code in SNC_point_locator");
       SM_point_locator L(&*v);
       //      Object_handle so = L.locate(s.source()-s.target(), true);
       Object_handle so = L.locate(s.source()-s.target());
@@ -1282,7 +1275,7 @@ public:
   SNC_point_locator_naive() : initialized(false) {}
   virtual void initialize(SNC_structure* W) { 
     CGAL_NEF_TIMER(ct_t.start());
-    std::strcpy(this->version_, "Naive Point Locator (tm)");
+    this->version_ = std::string("Naive Point Locator (tm)");
     CGAL_NEF_CLOG(version());
     CGAL_assertion( W != NULL);
     Base::initialize(W); 
