@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Triangulation/include/CGAL/Triangulation_data_structure.h $
+// $Id: Triangulation_data_structure.h 21d53cd 2018-11-12T09:58:14+01:00 Sebastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 //
 // Author(s)    : Samuel Hornus
 
@@ -22,6 +23,7 @@
 
 #include <CGAL/license/Triangulation.h>
 
+#include <CGAL/disable_warnings.h>
 
 #include <CGAL/basic.h>
 #include <CGAL/Default.h>
@@ -1390,7 +1392,9 @@ Triangulation_data_structure<Dimen, Vb, Fcb>
     std::size_t i = 0;
     while( i < m )
     {
-        Full_cell_handle s = new_full_cell();
+        Full_cell_handle s = (i==0 && full_cells_.size()==1 )
+                           ? full_cells_begin()
+                           : new_full_cell();
         full_cells.push_back(s);
         for( int j = 0; j <= cd; ++j )
         {
@@ -1603,4 +1607,6 @@ operator<<(std::ostream & os, const Triangulation_data_structure<Dimen, Vb, Fcb>
 
 } //namespace CGAL
 
+#include <CGAL/enable_warnings.h>
+
 #endif // CGAL_TRIANGULATION_DATA_STRUCTURE_H
