@@ -11,8 +11,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/GraphicsView/include/CGAL/export/Qt.h $
+// $Id: Qt.h ff26773 2017-11-11T20:20:26+01:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0+
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -23,9 +24,11 @@
 #include <CGAL/config.h>
 #include <CGAL/export/helpers.h>
 
-#if defined(CGAL_BUILD_SHARED_LIBS)
+#if ( defined(CGAL_BUILD_SHARED_LIBS) && ( ! defined(CGAL_HEADER_ONLY) ) ) \
+  || defined(CGAL_USE_Qt5_RESOURCES)
 
-#  if defined(CGAL_Qt5_EXPORTS) // defined by CMake or in cpp files of the dll
+#  if defined(CGAL_Qt5_EXPORTS) || defined(CGAL_USE_Qt5_RESOURCES)
+// defined by CMake or in cpp files of the dll
 
 #    define CGAL_QT_EXPORT CGAL_DLL_EXPORT
 #    define CGAL_QT_EXPIMP_TEMPLATE
