@@ -1,5 +1,6 @@
-// Copyright (c) 2000  
-// Utrecht University (The Netherlands),
+// Copyright (c) 2010 
+// GeometryFactory (France).
+// Copyright (c) 1997-2004  Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
@@ -16,19 +17,18 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Intersections_3/include/CGAL/intersection_3_1.h $
+// $Id: intersection_3_1.h 09c7fe1 2018-02-17T16:14:51+00:00 Andreas Fabri
 // SPDX-License-Identifier: LGPL-3.0+
 // 
 //
-// Author(s)     : Geert-Jan Giezeman
+// Author(s)     : Geert-Jan Giezeman <geert@cs.uu.nl>
+//                 Sebastien Loriot <Sebastien.Loriot@geometryfactory.com>
 
+#ifndef CGAL_INTERSECTION_3_1_H
+#define CGAL_INTERSECTION_3_1_H
 
+#include <CGAL/Intersections_3/internal/bbox_intersection_3.h>
+#include <CGAL/Intersections_3/internal/intersection_3_1_impl.h>
 
-#ifndef CGAL_INTERSECTION_2_3_H
-#define CGAL_INTERSECTION_2_3_H
-
-#include <CGAL/Circle_2_Circle_2_intersection.h>
-#include <CGAL/Circle_2_Line_2_intersection.h>
-
-#endif
+#endif // CGAL_INTERSECTION_3_1_H
