@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.3/Skin_surface_3/include/CGAL/triangulate_power_diagram_3.h $
+// $Id: triangulate_power_diagram_3.h 93cfd56 2018-11-20T16:54:30+01:00 Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0+
 //
 //
@@ -558,7 +558,7 @@ get_orthocenter(Rt_Simplex const &s)
            r2t_converter_object(e.first->vertex(e.third)->point()));
     break;
   case 2:
-    f=s;
+    f= Rt_Facet(s);
     result = orthocenter_obj(
            r2t_converter_object(
               f.first->vertex((f.second+1)&3)->point()),
